<?php
/**
 * @file
 * Default theme implementation to display a single Drupal page.
 *
 * The doctype, html, head and body tags are not in this template. Instead they
 * can be found in the html.tpl.php template in this directory.
 *
 * Available variables:
 *
 * General utility variables:
 * - $base_path: The base URL path of the Drupal installation. At the very
 *   least, this will always default to /.
 * - $directory: The directory the template is located in, e.g. modules/system
 *   or themes/bartik.
 * - $is_front: TRUE if the current page is the front page.
 * - $logged_in: TRUE if the user is registered and signed in.
 * - $is_admin: TRUE if the user has permission to access administration pages.
 *
 * Site identity:
 * - $front_page: The URL of the front page. Use this instead of $base_path,
 *   when linking to the front page. This includes the language domain or
 *   prefix.
 * - $logo: The path to the logo image, as defined in theme configuration.
 * - $site_name: The name of the site, empty when display has been disabled
 *   in theme settings.
 * - $site_slogan: The slogan of the site, empty when display has been disabled
 *   in theme settings.
 *
 * Navigation:
 * - $main_menu (array): An array containing the Main menu links for the
 *   site, if they have been configured.
 * - $secondary_menu (array): An array containing the Secondary menu links for
 *   the site, if they have been configured.
 * - $breadcrumb: The breadcrumb trail for the current page.
 *
 * Page content (in order of occurrence in the default page.tpl.php):
 * - $title_prefix (array): An array containing additional output populated by
 *   modules, intended to be displayed in front of the main title tag that
 *   appears in the template.
 * - $title: The page title, for use in the actual HTML content.
 * - $title_suffix (array): An array containing additional output populated by
 *   modules, intended to be displayed after the main title tag that appears in
 *   the template.
 * - $messages: HTML for status and error messages. Should be displayed
 *   prominently.
 * - $tabs (array): Tabs linking to any sub-pages beneath the current page
 *   (e.g., the view and edit tabs when displaying a node).
 * - $action_links (array): Actions local to the page, such as 'Add menu' on the
 *   menu administration interface.
 * - $feed_icons: A string of all feed icons for the current page.
 * - $node: The node object, if there is an automatically-loaded node
 *   associated with the page, and the node ID is the second argument
 *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
 *   comment/reply/12345).
 *
 * Variables added in preprocess function:
 * - $user_pictire: obrázek autora příspěvku, pokud není prázdné $node
 * 
 * Regions:
 * - regions[page_top] = Page Top
 * - regions[header_nav] = Header Navigation
 * - regions[highlighted] = Highlighted
 * - regions[promoted] = Promoted
 * - regions[rest_sticky] = Rest Sticky
 * - regions[share] = Sharing Spot
 * - regions[help] = Help
 * - regions[content] = Content
 * - regions[related] = Related Posts
 * - regions[sidebar] = Sidebar
 * - regions[footer1] = Footer 1
 * - regions[footer2] = Footer 2
 * - regions[footer3] = Footer 3
 * - regions[footer4] = Footer 4
 * - regions[page_bottom] = Page Bottom
 *
 * @see template_preprocess()
 * @see template_preprocess_page()
 * @see template_process()
 * @see html.tpl.php
 *
 * @ingroup themeable
 */

// prevedeni data na pozadovany format
if (!empty($node)) {
    $formatted_date = format_date($node->created, 'custom', 'd. m. Y');
}
?>

<div id="page-wrapper">
    <div id="page">
        <header id="head">
            <div class="header-wrapper">
                <?php print render($page['header_nav']); ?>
                <?php if ($logo): ?>
                    <div class="site-logo">
                        <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home" id="logo">
                           <?php if (!$title): ?>
                            <h1>
                                <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
                            </h1>
                            <?php else: ?>
                                <img src="<?php print $logo; ?>" alt="<?php print t('Home'); ?>" />
                            <?php endif; ?>
                        </a>
                    </div> <!-- /#site-logo -->
                <?php else: ?>
                <?php if ($site_name || $site_slogan): ?>
                    <div id="name-and-slogan">
                        <?php if ($site_name): ?>
                            <?php if ($title): ?>
                                <div id="site-name">
                                    <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                                        <span><?php print $site_name; ?></span>
                                    </a>
                                </div>
                            <?php else: ?>
                                <h1 id="site-name">
                                    <a href="<?php print $front_page; ?>" title="<?php print t('Home'); ?>" rel="home">
                                        <span><?php print $site_name; ?></span>
                                    </a>
                                </h1>
                            <?php endif; ?>
                        <?php endif; ?>
                        <?php if ($site_slogan): ?>
                            <div id="site-slogan"><?php print $site_slogan; ?></div>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
                <?php endif; ?>
            </div> <!-- /header-wrapper -->
        </header> <!-- /header -->
        <div class="wrapper">
            <?php if ($messages): ?> 
                <div id="messages-wrapper">    
                    <?php print $messages; ?>
                </div>    
            <?php endif; ?>
            <div id="main-wrapper">
                <main id="main" class="clearfix">
                    <?php if (!empty($node)): ?>
                        <article class="<?php print 'single-article ' . $classes; ?>"> 
                    <?php endif; ?>
                    <?php if ($is_front): ?>
                            <?php print render($page['promoted']); ?>
                            <div id="content" class="column">
                                <div class="section">
                                    <?php print render($page['rest_sticky']); ?>            
                                <?php endif; ?>
                                <?php if (!empty($node)): ?>
                                    <header id="article-header"> 
                                    <?php else: ?>      
                                        <?php if ($page['highlighted']): ?><div id="highlighted"><?php print render($page['highlighted']); ?></div><?php endif; ?>
                                    <?php endif; ?>
                                    <a id="main-content"></a>
                                    <?php print render($title_prefix); ?>
                                    <?php if ($title): ?><h1 class="title" id="page-title"><?php print $title; ?></h1><?php endif; ?>
                                    <?php print render($title_suffix); ?>
                                    <?php print render($page['help']); ?>
                                    <?php if ($action_links): ?><ul class="action-links"><?php print render($action_links); ?></ul><?php endif; ?>
                                    <?php if ($is_front): ?>
                                        <h2 class="promotion">Všechny články:</h2>
                                        <section class="normal-posts">
                                            <?php print render($page['content']); ?>
                                        </section>
                                    <?php else: ?>
                                        <?php if (!empty($node)): ?>
                                            <div class="article-summary">
                                                <?php
                                                if (!empty($node->body[$node->language][0]['safe_summary'])) {
                                                    print $node->body[$node->language][0]['safe_summary'];
                                                } else {
                                                    print $node->body['und'][0]['safe_summary'];
                                                }
                                                ?>
                                            </div>
                                            <div class="social">
                                                <?php print render($page['share']); ?>
                                            </div>
                                            <div class="post-meta">
                                                <?php if (!empty($user_picture)): ?>
                                                    <div class="out-of-box">    
                                                    <?php print $user_picture; ?> 
                                                    </div>
                                                <?php endif; ?>
                                                <div class="in-the-box">
                                                    <span class="author-name"><?php print $node->name; ?></span>
                                                    <span class="post-date"> | <?php print $formatted_date; ?></span>

                                                    <?php if ($node->comment == COMMENT_NODE_OPEN): ?>
                                                        <span class="comments"> | <a href="#comments">
                                                        <?php print svetnaruce_get_comment_text($node->comment_count); ?>
                                                            </a></span>
                                                    <?php endif; ?>

                                                </div>
                                            </div> <!-- /post-meta -->

                                        </header> <!-- /article-header -->
                                    <?php endif; ?>

                                    <?php if ($tabs): ?>
                                        <div class="tabs">
                                        <?php print render($tabs); ?>
                                        </div>
                                        <?php endif; ?>

                                    <div id="content" class="column">
                                        <div class="section">
                                        <?php
                                        if ($title && !$is_front && empty($node)) {
                                            print t('<div class="normal-posts">');
                                        } else {
                                            print t('<div>');
                                        }

                                        print render($page['content']);
                                        print t('</div>');
                                        if ($page['related']){
                                            print render($page['related']);
                                        }
                                        ?>
                                <?php endif; ?>
                                        </div>
                                   </div> <!-- /#content -->

                                   <?php if ($page['sidebar']): ?>
                                   <aside id="sidebar" class="column sidebar">
                                       <div class="stick-wrapper">
                                            <?php
                                            $ad_path = path_to_theme() . '/ad-square.php';
                                            include_once $ad_path;
                                            ?>
                                            <div class="section">
                                                <?php print render($page['sidebar']); ?>
                                            </div>
                                        </div>
                                    </aside> <!-- /#sidebar -->
                                <?php endif; ?>

         
                        <?php if (!empty($node)): ?>
                            </article>  <!-- /article -->
                        <?php endif; ?>
                </main> <!-- /#main -->
            </div> <!-- /main-wrapper -->
                
            </div> <!-- /#wrapper -->
            
            </div> <!-- /#page -->
 </div> <!-- /#page-wrapper -->            
            
            <div class="clearer"></div>
                <footer>
                    <div id="footer-wrapper">
                        <?php
                        print t('<section>');
                        print render($page['footer1']);
                        print t('</section>');
                        print t('<div class="verticalline"></div>');
                        print t('<section>');
                        print render($page['footer2']);
                        print t('</section>');
                        print t('<div class="verticalline"></div>');
                        print t('<section>');
                        print render($page['footer3']);
                        print t('</section>');
                        print t('<div class="verticalline"></div>');
                        print t('<section>');
                        print render($page['footer4']);
                        print t('</section>');
                        ?>
                    </div>
                    <div class="clearer"></div>
                    <div class="copyright">
                        <?php print t('Copyright &copy;' . $site_name . ', ' . date("Y")); ?>
                    </div>
                </footer> <!-- /#footer -->
