<?php 

/**
 * Overrides theme_more_link().
 * Mění text z "More" na "Více"
 */
function svetnaruce_more_link($variables) {
  return '<div class="more-link">' . l(t('Více'), $variables ['url'], array('attributes' => array('title' => $variables ['title']))) . '</div>';
}

function YOURTHEME_preprocess_page(&$vars) {
  
}

/**
 * PREPROCESS FUNCTIONS
 */

/**
* 1) Přidává možnost vypisovat obrázek autora článku do page.tpl.php
*/
function svetnaruce_preprocess_page(&$variables) {
    if (!empty($variables['node'])) {
        $user = user_load($variables['node']->uid);
        if (!empty($user->picture)) {
            $user_picture = theme_image_style(
                    array(
                        'style_name' => 'medium',
                        'path' => check_url($user->picture->uri),
                        'width' => NULL,
                        'height' => NULL,
                        'attributes' => array(
                            'class' => 'avatar',
                            'width' => 40,
                            'height' => 40,
                        )
                    )
            );
            $variables['user_picture'] = $user_picture;
        } else {
            $default_path = variable_get('user_picture_default', '');   
            $user_picture = theme_image(
                    array(
                        'path' => $default_path,
                        'width' => NULL,
                        'height' => NULL,
                        'attributes' => array(
                            'class' => 'avatar',
                            'width' => 40,
                            'height' => 40,
                        )
                    )
            );
            $variables['user_picture'] = $user_picture;
        }
    }  
}

/**
* Přidává class 'footer-quarter' do každé ze 4 částí patičky
*/
function svetnaruce_preprocess_region(&$variables, $hook) {
    if($variables['region'] == "footer1" || $variables['region'] == "footer2" || $variables['region'] == "footer3" || $variables['region'] == "footer4"){
       $variables['classes_array'][] = 'footer-quarter';
    }
}

/**
 * Přidává do hlavičky link na stažení fontu z Google fonts + material ikony
 */
function svetnaruce_preprocess_html(&$variables) {
    drupal_add_css('http://fonts.googleapis.com/css?family=Roboto&subset=latin%2Clatin-ext&ver=4.3', array('type' => 'external'));
    drupal_add_css('https://fonts.googleapis.com/icon?family=Material+Icons', array('type' => 'external'));
}

/**
 * 1) Přidává do node.tpl.php proměnnou $formatted_date s požadovaným formátem data publikování článku
 * 2) Pomocí funkce get_comment_text() přidává proměnnou $comment_text
 * 3) Přidává proměnnou $ad s cestou k souboru šablony ad-inline.php
 */
function svetnaruce_preprocess_node(&$variables, $hook) {
    $formatted_date = format_date($variables['node']->created, 'custom', 'd. m. Y');
    $variables['formatted_date'] = $formatted_date;

    $variables['comment_text'] = svetnaruce_get_comment_text($variables['comment_count']);
    
    $adblock = file_get_contents(path_to_theme() . '/ad-inline.php');
    $variables['ad'] = $adblock;
}

/**
 * Upravuje datum komentáře na požadovaný tvar pro použití v comment.tpl.php
 */
function svetnaruce_preprocess_comment(&$variables) {
    $formatted_created = format_date($variables['comment']->created, 'custom', 'd. m. Y (G:i)');
    $variables['created'] = $formatted_created;
}

function svetnaruce_preprocess_field(&$variables) {
    if($variables['label'] == "Image") {
       $variables['label'] = "Obrázek";
       $variables['label_hidden'] = true;
    }
    
    if($variables['label'] == "Tags") {
       $variables['label'] = "Štítky";
    }
   
    // vložení reklamy za 1. odstavec do článku, pouze při plném zobrazení
    if($variables['element']['#field_name'] == "body" && $variables['element']['#entity_type'] == "node" && $variables['element']['#view_mode'] == "full" ) {
       $markup = $variables['items'][0]['#markup'];
       $closing_p = '</p>';
       $paragraph_id = 1;
       $ad = file_get_contents(path_to_theme() . '/ad-inline.php');
   
       $paragraphs = explode( $closing_p, $markup );
       
       foreach ($paragraphs as $index => $paragraph) {
            if ( trim( $paragraph ) ) {
                $paragraphs[$index] .= $closing_p;
            }
            if ( $paragraph_id == $index + 1 ) {
                $paragraphs[$index] .= $ad;
            }
        }
        $markup = implode( '', $paragraphs );
        $variables['items'][0]['#markup'] = $markup;
    }
    
}

/**
 * OTHER THAN PREPROCESS FUNCTIONS
 */


/**
 * Upravuje popisek buttonu a přidává placeholder do vyhledávácího formuláře
 */
function svetnaruce_form_search_block_form_alter(&$form, &$form_state, $form_id) {
    $form['actions']['submit']['#value'] = t('Hledat');
    $form['search_block_form']['#attributes']['placeholder'] = t('Vyhledat..');
}


/**
 * Overrides theme_menu_link().
 * Přidává možnost "prázdného" odkazu v menu při odkazování na článek s url "nolink"
 */
function svetnaruce_menu_link(array $variables) {
  $element = $variables['element'];
  $sub_menu = '';

  if ($element['#below']) {
    $sub_menu = drupal_render($element['#below']);
  }
  if (strpos(url($element['#href']), 'nolink')) {
    $output = '<a class="nolink">' . $element['#title'] . '</a>';
  } else {
  $output = l($element['#title'], $element['#href'], $element['#localized_options']);
  }
  return '<li' . drupal_attributes($element['#attributes']) . '>' . $output . $sub_menu . "</li>\n";
}

/**
 * Odebírá link na CSS soubor system.menus.css
 */
function svetnaruce_css_alter(&$css) {
    unset($css[drupal_get_path('module','system').'/system.menus.css']);
}


/**
 *
 * overrides menu_pager()
 * 
 * Maže odkazy na LAST, FIRST a číslice stránek. Pokud jsme na první stránce, přidává tlačítku next class="align-center"
 */
function svetnaruce_pager($variables) {
  $tags = $variables['tags'];
  $element = $variables['element'];
  $parameters = $variables['parameters'];
  $quantity = $variables['quantity'];
  global $pager_page_array, $pager_total;

  // Calculate various markers within this pager piece:
  // Middle is used to "center" pages around the current page.
  $pager_middle = ceil($quantity / 2);
  // current is the page we are currently paged to
  $pager_current = $pager_page_array[$element] + 1;
  // first is the first page listed by this pager piece (re quantity)
  $pager_first = $pager_current - $pager_middle + 1;
  // last is the last page listed by this pager piece (re quantity)
  $pager_last = $pager_current + $quantity - $pager_middle;
  // max is the maximum page number
  $pager_max = $pager_total[$element];
  // End of marker calculations.

  // Prepare for generation loop.
  $i = $pager_first;
  if ($pager_last > $pager_max) {
    // Adjust "center" if at end of query.
    $i = $i + ($pager_max - $pager_last);
    $pager_last = $pager_max;
  }
  if ($i <= 0) {
    // Adjust "center" if at start of query.
    $pager_last = $pager_last + (1 - $i);
    $i = 1;
  }
  // End of generation loop preparation.

  //$li_first = theme('pager_first', array('text' => (isset($tags[0]) ? $tags[0] : t('« first')), 'element' => $element, 'parameters' => $parameters));
  $li_previous = theme('pager_previous', array('text' => (isset($tags[1]) ? $tags[1] : t('Novější příspěvky')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters));
  $li_next = theme('pager_next', array('text' => (isset($tags[3]) ? $tags[3] : t('Starší příspěvky')), 'element' => $element, 'interval' => 1, 'parameters' => $parameters));
  //$li_last = theme('pager_last', array('text' => (isset($tags[4]) ? $tags[4] : t('last »')), 'element' => $element, 'parameters' => $parameters));
  
  if ($pager_total[$element] > 1) {

        if ($li_previous) {
            $items[] = array(
                'class' => array('pager-previous'),
                'data' => $li_previous,
            );
        }

        // Pokud jsme na první stránce - tzn. neobjevuje se "previous"
        if ($pager_current == $i) {
            if ($li_next) {
                $items[] = array(
                    'class' => array('pager-next align-center'),
                    'data' => $li_next,
                );
            }
        } else {
            if ($li_next) {
                $items[] = array(
                    'class' => array('pager-next'),
                    'data' => $li_next,
                );
            }
        }

        return '<h2 class="element-invisible">' . t('Pages') . '</h2>' . theme('item_list', array(
                    'items' => $items,
                    'attributes' => array('class' => array('pager')),
        ));
    }
}

/**
 * Připravuje správný český tvar slova "komentář" pro různé počty komentářů
 * Pokud článek nemá žádné komentáře, vypíše pouze "Komentáře" bez počtu
 */
function svetnaruce_get_comment_text($comment_count) {
    $comment_text = '';
        switch ($comment_count) {
            case 0:
                $comment_text = '<span class="comments-label no-comennts">Komentáře</span>';
                break;
            case 1:
                $comment_text = '<span class="comments-number">'.$comment_count.'</span><span class="comments-label"> komentář</span>';
                break;
            case 2:
            case 3:
            case 4:
                $comment_text = '<span class="comments-number">'.$comment_count.'</span><span class="comments-label"> komentáře</span>';
                break;
            default:
                $comment_text = '<span class="comments-number">'.$comment_count.'</span><span class="comments-label"> komentářů</span>';           
        }
        return $comment_text;
}


/**
 * Returns HTML for a field_tags.
 * 
 * Overrides theme_field().
 *
 *
 * Pokud jde o "dield-tags", tedy štítky u článku, přidává jim css třídu pro náhodou barvu štítku
 * 
 * @param $variables
 *   An associative array containing:
 *   - label_hidden: A boolean indicating to show or hide the field label.
 *   - title_attributes: A string containing the attributes for the title.
 *   - label: The label for the field.
 *   - content_attributes: A string containing the attributes for the content's
 *     div.
 *   - items: An array of field items.
 *   - item_attributes: An array of attributes for each item.
 *   - classes: A string containing the classes for the wrapping div.
 *   - attributes: A string containing the attributes for the wrapping div.
 *
 * @see template_preprocess_field()
 * @see template_process_field()
 * @see field.tpl.php
 *
 * @ingroup themeable
 */
function svetnaruce_field__field_tags($variables) {
  $output = '';

  // Render the label, if it's not hidden.
  if (!$variables['label_hidden']) {
    $output .= '<div class="field-label"' . $variables['title_attributes'] . '>' . $variables['label'] . ':&nbsp;</div>';
  }

  // Render the items.
  $output .= '<div class="field-items"' . $variables['content_attributes'] . '>';
  foreach ($variables['items'] as $delta => $item) {
    $classes = 'field-item ' . ($delta % 2 ? 'odd' : 'even');
    
    if($variables['field_name_css'] == "field-tags") {
            $classes .= ' tag-color-'.rand(1,10).'';
    }
    
    
    $output .= '<div class="' . $classes . '"' . $variables['item_attributes'][$delta] . '>' . drupal_render($item) . '</div>';
  }
  $output .= '</div>';

  // Render the top-level DIV.
  $output = '<div class="' . $variables['classes'] . '"' . $variables['attributes'] . '>' . $output . '</div>';

  return $output;
}
